@@ -4,10 +4,11 @@
 # related or neighboring rights to this document.  Attribution is requested
 # but not required.
 use strict; use warnings FATAL => 'all'; use utf8;
-use feature qw(say state);
+use feature qw(say state lexical_subs);
+no warnings qw(experimental::lexical_subs);
 
 package Spreadsheet::Edit::IO;
-$Spreadsheet::Edit::IO::VERSION = '2.103';
+$Spreadsheet::Edit::IO::VERSION = '3.000';
 # This module is derived from the old never-released Text:CSV::Spreadsheet
 
 use Exporter 'import';
