@@ -8,27 +8,26 @@ use strict; use warnings FATAL => 'all'; use v5.20;
 use utf8;
 
 package Spreadsheet::Edit::Preload;
-$Spreadsheet::Edit::Preload::VERSION = '2.103';
+$Spreadsheet::Edit::Preload::VERSION = '3.000';
 use Carp;
 use Import::Into;
 require Spreadsheet::Edit;
 our @CARP_NOT = ('Spreadsheet::Edit');
 
 sub import {
+#use Data::Dumper::Interp; say dvis '###Preload import @_';
   my $pkg = shift;  # that's us
-  my ($inpath, @args) = @_;
+
   my $callpkg = caller($Exporter::ExportLevel);
 
   # Import Spreadsheet::Edit and the usual variables for the user
   Spreadsheet::Edit->import::into($callpkg, ':all');
 
-  # Load the spreadsheet and tie column variable in caller's package
-  my $sh = Spreadsheet::Edit->new->read_spreadsheet(@args);
-
-  if (ref($args[0]) eq "HASH" && exists $args[0]->{title_rx}) {
-    $sh->title_rx( $args[0]->{title_rx} );
-  }
+  # Load the spreadsheet
+  my $sh = Spreadsheet::Edit->new->read_spreadsheet(@_);
+#use Data::Dumper::Interp; say visnew->Objects(0)->dvis('###Preload GOT $sh');
 
+  # Tie variables in the caller's package
   $sh->tie_column_vars({package => $callpkg}, ':all');
 
   # Make it the 'current sheet' in the caller's package
